"use client"

import LoadingItem from "@/components/loading-item"
import { Separator } from "@/components/ui/separator"
import { useEffect } from "react"
import { useInView } from "react-intersection-observer"
import { IInfiniteGweets } from "../types"
import { Gweet } from "./gweet"

export const InfiniteGweets = ({
    gweets,
    isSuccess,
    isFetchingNextPage,
    fetchNextPage,
    hasNextPage,
    isFetchingPreviousPage,
    fetchPreviousPage,
    hasPreviousPage,
}: {
    gweets: IInfiniteGweets
    isSuccess: boolean | undefined
    isFetchingNextPage?: boolean | undefined
    fetchNextPage?: () => Promise<any> | void
    hasNextPage?: boolean | undefined
    isFetchingPreviousPage?: boolean | undefined
    fetchPreviousPage?: () => Promise<any> | void
    hasPreviousPage?: boolean | undefined
}) => {
    const { ref, inView } = useInView()

    useEffect(() => {
        if (inView && hasNextPage) {
            if (fetchNextPage) fetchNextPage()
        }
        if (inView && hasPreviousPage) {
            if (fetchPreviousPage) fetchPreviousPage()
        }
    }, [inView, hasNextPage, fetchNextPage, hasPreviousPage, fetchPreviousPage])

    return (
        <>
            {/* {isFetchingPreviousPage && <LoadingItem />} */}

            {isSuccess &&
                gweets?.pages?.map((page) => {
                    return page?.gweets?.map((gweet, index) => (
                        <div
                            ref={index === page.gweets.length - 4 ? ref : undefined}
                            key={gweet.id}
                        >
                            <Gweet gweet={gweet} />
                            {index !== page.gweets.length - 1 && (
                                <div className="px-6">
                                    <Separator className="my-3" />
                                </div>
                            )}
                        </div>
                    ))
                })}

            {isFetchingNextPage && <LoadingItem />}
        </>
    )
}