import GameItem from "@/components/game-item"
import { db } from "@/lib/db"
import { getFavoriteGames } from "@/lib/igdb"
import { getCurrentUser } from "@/lib/session"
import { IGame } from "@/types/igdb-types"
import { redirect } from "next/navigation"

export const UserGames = async ({ username }: { username: string }) => {
    const user = await getCurrentUser()

    const sessionUser = await db.user.findFirst({
        where: {
            id: user?.id
        },
        include: {
            following: true,
            followers: true
        }
    })

    const fullUser = await db.user.findFirst({
        where: {
            username: username
        },
        include: {
            following: true,
            followers: true
        }
    })

    if (!fullUser) {
        redirect('/home')
    }

    let favoritegames = undefined
    let playingGames = undefined
    let finishedGames = undefined
    let planningGames = undefined

    if (fullUser?.favGameList?.length !== 0 && fullUser?.favGameList?.length != undefined) {
        favoritegames = await getFavoriteGames(fullUser?.favGameList!)
    }
    if (fullUser?.playingGameList?.length !== 0) {
        playingGames = await getFavoriteGames(fullUser?.playingGameList!)
    }
    if (fullUser?.finishedGameList?.length !== 0) {
        finishedGames = await getFavoriteGames(fullUser?.finishedGameList!)
    }
    if (fullUser?.planningGameList?.length !== 0) {
        planningGames = await getFavoriteGames(fullUser?.planningGameList!)
    }

    return (
        <div className="p-3 space-y-12">
            <div>
                <h1 className="text-2xl font-bold pb-3">Favorite Games</h1>
                {favoritegames ?
                    <div className="grid grid-cols-1 ss:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4 2xl:grid-cols-5 gap-4 lg:gap-8 items-center">
                        {favoritegames.map((game: IGame) => (
                            <GameItem id={game.id} name={game.name} cover={game.cover} key={game.id} />
                        ))}
                    </div>
                    :
                    <span>No favorites currently...</span>
                }
            </div>

            <div>
                <h1 className="text-2xl font-bold pb-3">Currently playing</h1>
                {playingGames ?
                    <div className="grid grid-cols-1 ss:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4 2xl:grid-cols-5 gap-4 lg:gap-8 items-center">
                        {playingGames.map((game: IGame) => (
                            <GameItem id={game.id} name={game.name} cover={game.cover} key={game.id} />
                        ))}
                    </div>
                    :
                    <p>Currently not playing any games...</p>
                }
            </div>

            <div>
                <h1 className="text-2xl font-bold pb-3">Planning to play</h1>
                {planningGames ?
                    <div className="grid grid-cols-1 ss:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4 2xl:grid-cols-5 gap-4 lg:gap-8 items-center">
                        {planningGames.map((game: IGame) => (
                            <GameItem id={game.id} name={game.name} cover={game.cover} key={game.id} />
                        ))}
                    </div>
                    :
                    <p>Currently not planning to play any games...</p>}
            </div>

            <div>
                <h1 className="text-2xl font-bold pb-3">Finished Games</h1>
                {finishedGames ?
                    <div className="grid grid-cols-1 ss:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4 2xl:grid-cols-5 gap-4 lg:gap-8 items-center">
                        {finishedGames.map((game: IGame) => (
                            <GameItem id={game.id} name={game.name} cover={game.cover} key={game.id} />
                        ))}
                    </div>
                    :
                    <p>No finished games...</p>}
            </div>
        </div >
    )
}