import { useMutation, useQueryClient } from "@tanstack/react-query"

import { followUser } from "../api/follow-user"
import { unfollowUser } from "../api/unfollow-user"

export const useFollow = (type: "follow" | "unfollow") => {
    const queryClient = useQueryClient()

    return useMutation(
        ({
            userId,
        }: {
            userId: string
        }) => {
            return type === "follow"
                ? followUser(userId)
                : unfollowUser(userId)
        },

        {
            onSuccess: () => {
                if (process.env.NODE_ENV === "development") console.log("success")
            },

            onError: (error) => {
                if (process.env.NODE_ENV === "development") console.log(error)
            },

            onSettled: ({ userId }) => {
                queryClient.invalidateQueries(["users", userId])
                queryClient.invalidateQueries(["tweets"])
            },
        },
    )
}